package Shipment::FedEx::WSDL::TrackTypes::TrackAdvanceNotificationDetail;
$Shipment::FedEx::WSDL::TrackTypes::TrackAdvanceNotificationDetail::VERSION = '3.01';
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns {'http://fedex.com/ws/track/v9'}

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{    # BLOCK to scope variables

    my %EstimatedTimeOfArrival_of : ATTR(:get<EstimatedTimeOfArrival>);
    my %Reason_of : ATTR(:get<Reason>);
    my %Status_of : ATTR(:get<Status>);
    my %StatusDescription_of : ATTR(:get<StatusDescription>);
    my %StatusTime_of : ATTR(:get<StatusTime>);

    __PACKAGE__->_factory(
        [   qw(        EstimatedTimeOfArrival
              Reason
              Status
              StatusDescription
              StatusTime

              )
        ],
        {   'EstimatedTimeOfArrival' => \%EstimatedTimeOfArrival_of,
            'Reason'                 => \%Reason_of,
            'Status'                 => \%Status_of,
            'StatusDescription'      => \%StatusDescription_of,
            'StatusTime'             => \%StatusTime_of,
        },
        {   'EstimatedTimeOfArrival' =>
              'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
            'Reason' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
            'Status' =>
              'Shipment::FedEx::WSDL::TrackTypes::TrackAdvanceNotificationStatusType',
            'StatusDescription' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
            'StatusTime' => 'SOAP::WSDL::XSD::Typelib::Builtin::dateTime',
        },
        {

            'EstimatedTimeOfArrival' => 'EstimatedTimeOfArrival',
            'Reason'                 => 'Reason',
            'Status'                 => 'Status',
            'StatusDescription'      => 'StatusDescription',
            'StatusTime'             => 'StatusTime',
        }
    );

}    # end BLOCK


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Shipment::FedEx::WSDL::TrackTypes::TrackAdvanceNotificationDetail

=head1 VERSION

version 3.01

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
TrackAdvanceNotificationDetail from the namespace http://fedex.com/ws/track/v9.

=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * EstimatedTimeOfArrival

=item * Reason

=item * Status

=item * StatusDescription

=item * StatusTime

=back

=head1 NAME

Shipment::FedEx::WSDL::TrackTypes::TrackAdvanceNotificationDetail

=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # Shipment::FedEx::WSDL::TrackTypes::TrackAdvanceNotificationDetail
   EstimatedTimeOfArrival =>  $some_value, # dateTime
   Reason =>  $some_value, # string
   Status => $some_value, # TrackAdvanceNotificationStatusType
   StatusDescription =>  $some_value, # string
   StatusTime =>  $some_value, # dateTime
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=head1 AUTHOR

Andrew Baerg <baergaj@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Andrew Baerg.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
