package Shipment::Temando::WSDL::Types::CarrierPreference;
$Shipment::Temando::WSDL::Types::CarrierPreference::VERSION = '3.01';
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(0);

sub get_xmlns {
    'http://'
      . $Shipment::Temando::WSDL::Interfaces::quoting_Service::quoting_port::ns_url
      . '/schema/2009_06/common.xsd';
}

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{    # BLOCK to scope variables

    my %carrierId_of : ATTR(:get<carrierId>);
    my %deliveryMethods_of : ATTR(:get<deliveryMethods>);

    __PACKAGE__->_factory(
        [   qw(        carrierId
              deliveryMethods

              )
        ],
        {   'carrierId'       => \%carrierId_of,
            'deliveryMethods' => \%deliveryMethods_of,
        },
        {   'carrierId' => 'Shipment::Temando::WSDL::Types::CarrierId',

            'deliveryMethods' =>
              'Shipment::Temando::WSDL::Types::CarrierPreference::_deliveryMethods',
        },
        {

            'carrierId'       => 'carrierId',
            'deliveryMethods' => 'deliveryMethods',
        }
    );

}    # end BLOCK


package Shipment::Temando::WSDL::Types::CarrierPreference::_deliveryMethods;
$Shipment::Temando::WSDL::Types::CarrierPreference::_deliveryMethods::VERSION
  = '3.01';
use strict;
use warnings;
{
    our $XML_ATTRIBUTE_CLASS;
    undef $XML_ATTRIBUTE_CLASS;

    sub __get_attr_class {
        return $XML_ATTRIBUTE_CLASS;
    }

    use Class::Std::Fast::Storable constructor => 'none';
    use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

    Class::Std::initialize();

    {    # BLOCK to scope variables

        my %deliveryMethod_of : ATTR(:get<deliveryMethod>);

        __PACKAGE__->_factory(
            [   qw(        deliveryMethod

                  )
            ],
            {'deliveryMethod' => \%deliveryMethod_of,},
            {   'deliveryMethod' =>
                  'Shipment::Temando::WSDL::Types::DeliveryMethod',
            },
            {

                'deliveryMethod' => 'deliveryMethod',
            }
        );

    }    # end BLOCK


}


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Shipment::Temando::WSDL::Types::CarrierPreference

=head1 VERSION

version 3.01

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
CarrierPreference from the namespace http://' . $Shipment::Temando::WSDL::Interfaces::quoting_Service::quoting_port::ns_url . '/schema/2009_06/common.xsd.

=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * carrierId (min/maxOccurs: 0/1)

=item * deliveryMethods (min/maxOccurs: 0/1)

=back

=head1 NAME

Shipment::Temando::WSDL::Types::CarrierPreference

=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # Shipment::Temando::WSDL::Types::CarrierPreference
   carrierId => $some_value, # CarrierId
   deliveryMethods =>  {
     deliveryMethod => $some_value, # DeliveryMethod
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=head1 AUTHOR

Andrew Baerg <baergaj@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Andrew Baerg.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
